==> haskell-tz-0.1.3.6-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tz
version:              0.1.3.6
visibility:           public
id:                   tz-0.1.3.6-9eOITf7bJkqAkfhW5M6OBu
key:                  tz-0.1.3.6-9eOITf7bJkqAkfhW5M6OBu
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tz
synopsis:             Efficient time zone handling
description:
    The goal of this package is to provide a library that can read time
    zone info files (aka. Olson files), and does time zone conversions
    in a /pure/ and /efficient/ way.

    We also provide platform-independent and/or compiled-in access to
    the standard Time Zone Dabase by the means of the companion @tzdata@
    package <http://hackage.haskell.org/package/tzdata>.

    The package is currently in an alpha phase, I'\''m still experimenting
    with different ideas wrt. scope\/API\/implementation\/etc. All
    comments are welcome!

category:             Data
abi:                  90edac74b94188a78aab7d438576308d
exposed:              True
exposed-modules:
    Data.Time.Zones Data.Time.Zones.All Data.Time.Zones.Internal
    Data.Time.Zones.Read Data.Time.Zones.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tz
hs-libraries:         HStz-0.1.3.6-9eOITf7bJkqAkfhW5M6OBu
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    time-1.12.2 tzdata-0.2.20250115.0-9yQP2Lwc4nULQYStQPGh27
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:   /usr/share/doc/haskell-tz/html/tz.haddock
haddock-html:         /usr/share/doc/haskell-tz/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tz-0.1.3.6-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tz
version:              0.1.3.6
visibility:           public
id:                   tz-0.1.3.6-38wDXRQ9wcXGAFGsfRWLxz
key:                  tz-0.1.3.6-38wDXRQ9wcXGAFGsfRWLxz
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tz
synopsis:             Efficient time zone handling
description:
    The goal of this package is to provide a library that can read time
    zone info files (aka. Olson files), and does time zone conversions
    in a /pure/ and /efficient/ way.

    We also provide platform-independent and/or compiled-in access to
    the standard Time Zone Dabase by the means of the companion @tzdata@
    package <http://hackage.haskell.org/package/tzdata>.

    The package is currently in an alpha phase, I'\''m still experimenting
    with different ideas wrt. scope\/API\/implementation\/etc. All
    comments are welcome!

category:             Data
abi:                  a1a1ed4a983721afe71694eed49f708f
exposed:              True
exposed-modules:
    Data.Time.Zones Data.Time.Zones.All Data.Time.Zones.Internal
    Data.Time.Zones.Read Data.Time.Zones.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tz
hs-libraries:         HStz-0.1.3.6-38wDXRQ9wcXGAFGsfRWLxz
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    time-1.12.2 tzdata-0.2.20250115.0-1BIU9INZNpR50ahHxl35jc
    vector-0.13.2.0-F0gUvA5SUIr11j4RVHYOTP

haddock-interfaces:   /usr/share/doc/haskell-tz/html/tz.haddock
haddock-html:         /usr/share/doc/haskell-tz/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
